@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2008, 2009, 2010 Net-ng.
+# Copyright (c) 2008-2012 Net-ng.
 # All rights reserved.
 #
 # This software is licensed under the BSD License, as described in
@@ -67,18 +67,16 @@ def entity_getstate(entity):
     state = entity._sa_instance_state   # SQLAlchemy managed state
 
     if state.key:
-        key = state.key[1]                       # Primary key
         attrs = set(state.manager.local_attrs)   # SQLAlchemy managed attributes
         attrs.add('_sa_instance_state')
     else:
-        key = None
         attrs = ()
 
     # ``d`` is the dictionary of the _not_ SQLAlchemy managed attributes
     d = dict([(k, v) for (k, v) in entity.__dict__.items() if k not in attrs])
 
     # Keep only the primary key from the SQLAlchemy state
-    d['_sa_key'] = key
+    d['_sa_key'] = state.key[1] if state.key else None
 
     return d
 
@@ -126,5 +124,5 @@ def set_metadata(metadata, database_uri, database_debug, engine_settings):
       - ``engine_settings`` -- dedicated parameters for the used database engine
     """
     if not metadata.bind:
-        metadata.bind = _engines.setdefault(database_uri, sqlalchemy.create_engine(database_uri, echo=database_debug, **engine_settings))
+        metadata.bind = _engines.setdefault(database_uri, sqlalchemy.engine_from_config(engine_settings, '', echo=database_debug, url=database_uri))
         setup_all()
