@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2008, 2009, 2010 Net-ng.
+# Copyright (c) 2008-2012 Net-ng.
 # All rights reserved.
 #
 # This software is licensed under the BSD License, as described in
@@ -14,6 +14,7 @@ from nagare.namespaces import xhtml_base
 from nagare.namespaces import xml
 from nagare import callbacks
 from nagare import wsgi
+from nagare import local
 from nagare.sessions.memory_sessions import SessionsWithPickledStates
 from nagare import presentation
 
@@ -24,6 +25,9 @@ from paste.fixture import TestApp
 import os
 
 def create_FixtureApp(app):
+    local.worker = local.Process()
+    local.request = local.Process()
+
     app = wsgi.create_WSGIApp(app)
     app.set_sessions_manager(SessionsWithPickledStates())
     app.start()
