@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2008, 2009, 2010 Net-ng.
+# Copyright (c) 2008-2012 Net-ng.
 # All rights reserved.
 #
 # This software is licensed under the BSD License, as described in
@@ -7,9 +7,11 @@
 # this distribution.
 #--
 
-from nagare import wsgi
+from nagare import local, wsgi
 from nagare.sessions import ExpirationError, common
 
+local.request = local.Process()
+
 def create_environ():
     return {
             'REQUEST_METHOD' : 'GET',
@@ -51,7 +53,7 @@ class ExpiredSessionManager(common.Sessions):
         raise ExpirationError()
 
 class App(wsgi.WSGIApp):
-    def __init__(self, session_manager=SessionManager()):
+    def __init__(self, session_manager=SessionManager(local.DummyLock)):
         super(App, self).__init__(lambda: None)
         self.sessions = session_manager
 
@@ -75,5 +77,5 @@ def test_request_validity2():
 
 def test_bad_session():
     """Request - session expired"""
-    r = process_request(App(session_manager=ExpiredSessionManager()))
+    r = process_request(App(session_manager=ExpiredSessionManager(local.DummyLock)))
     assert (r.status_code == 301) and r['Location'] == 'http://localhost:8080/app/'
