@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2008, 2009, 2010 Net-ng.
+# Copyright (c) 2008-2012 Net-ng.
 # All rights reserved.
 #
 # This software is licensed under the BSD License, as described in
@@ -52,7 +52,7 @@ class Var(object):
         """Return or set the value
 
         In:
-          - ``v` -- if given, ``v`` becomes the new value
+          - ``v`` -- if given, ``v`` becomes the new value
 
         Return:
           - the variable value
